class Loader:

    def __init__(self, pkg, dir):
        if dir == ".":
            dir = ""
        dir = dir.replace("/", ".") + ".compiled."
        if pkg and pkg != "__main__":
            dir = pkg + "." + dir
        self.p = dir

    def load(self, name):
        name = name.replace(".", "_")
        return __import__(self.p + name, None, None, (name,)).render



from setuptools import setup


setup(name='utemplate',
      version='0.9.1',
      description="""Very lightweight, memory-efficient (uses generator
protocol), dependency-free template engine (compiles to Python source).
Particularly well suited for usage with MicroPython.org""",
      url='https://github.com/pfalcon/utemplate',
      author='Paul Sokolovsky',
      author_email='pfalcon@users.sourceforge.net',
      license='MIT',
      packages=['utemplate'])
